/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQtChart.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtChart.h"

#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractaxis.sip"
#include <qabstractaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractbarseries.sip"
#include <qabstractbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractseries.sip"
#include <qabstractseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qarealegendmarker.sip"
#include <qarealegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qareaseries.sip"
#include <qareaseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarcategoryaxis.sip"
#include <qbarcategoryaxis.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarlegendmarker.sip"
#include <qbarlegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarseries.sip"
#include <qbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarset.sip"
#include <qbarset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxplotlegendmarker.sip"
#include <qboxplotlegendmarker.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxplotseries.sip"
#include <qboxplotseries.h>
#line 34 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxplotseries.sip"
#include <qboxplotseries.h>
#line 51 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQBoxPlotSeries.cpp"

#line 28 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobject.sip"
#include <qobject.h>
#line 55 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQBoxPlotSeries.cpp"
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractaxis.sip"
#include <qabstractaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractbarseries.sip"
#include <qabstractbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractseries.sip"
#include <qabstractseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qarealegendmarker.sip"
#include <qarealegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qareaseries.sip"
#include <qareaseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarcategoryaxis.sip"
#include <qbarcategoryaxis.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarlegendmarker.sip"
#include <qbarlegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarseries.sip"
#include <qbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarset.sip"
#include <qbarset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxplotlegendmarker.sip"
#include <qboxplotlegendmarker.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxplotseries.sip"
#include <qboxplotseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxset.sip"
#include <qboxset.h>
#line 34 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxset.sip"
#include <qboxset.h>
#line 82 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQBoxPlotSeries.cpp"
#line 149 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 85 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQBoxPlotSeries.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qpen.sip"
#include <qpen.h>
#line 88 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQBoxPlotSeries.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qbrush.sip"
#include <qbrush.h>
#line 91 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQBoxPlotSeries.cpp"
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractaxis.sip"
#include <qabstractaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractbarseries.sip"
#include <qabstractbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractseries.sip"
#include <qabstractseries.h>
#line 32 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractseries.sip"
#include <qabstractseries.h>
#line 100 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQBoxPlotSeries.cpp"
#line 149 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 103 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQBoxPlotSeries.cpp"
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractaxis.sip"
#include <qabstractaxis.h>
#line 32 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractaxis.sip"
#include <qabstractaxis.h>
#line 108 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQBoxPlotSeries.cpp"
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractaxis.sip"
#include <qabstractaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractbarseries.sip"
#include <qabstractbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractseries.sip"
#include <qabstractseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qarealegendmarker.sip"
#include <qarealegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qareaseries.sip"
#include <qareaseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarcategoryaxis.sip"
#include <qbarcategoryaxis.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarlegendmarker.sip"
#include <qbarlegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarseries.sip"
#include <qbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarset.sip"
#include <qbarset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxplotlegendmarker.sip"
#include <qboxplotlegendmarker.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxplotseries.sip"
#include <qboxplotseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxset.sip"
#include <qboxset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlesticklegendmarker.sip"
#include <qcandlesticklegendmarker.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickmodelmapper.sip"
#include <qcandlestickmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickseries.sip"
#include <qcandlestickseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickset.sip"
#include <qcandlestickset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcategoryaxis.sip"
#include <qcategoryaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qchart.sip"
#include <qchart.h>
#line 32 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qchart.sip"
#include <qchart.h>
#line 147 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQBoxPlotSeries.cpp"
#line 27 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qstring.sip"
#include <qstring.h>
#line 150 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQBoxPlotSeries.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 146 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 155 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQBoxPlotSeries.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 158 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQBoxPlotSeries.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 161 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQBoxPlotSeries.cpp"
#line 252 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 164 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQBoxPlotSeries.cpp"
#line 240 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 167 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQBoxPlotSeries.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qvariant.sip"
#include <qvariant.h>
#line 170 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQBoxPlotSeries.cpp"
#line 38 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 173 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQBoxPlotSeries.cpp"
#line 30 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 176 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQBoxPlotSeries.cpp"
#line 149 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 179 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQBoxPlotSeries.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 182 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQBoxPlotSeries.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qthread.sip"
#include <qthread.h>
#line 185 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQBoxPlotSeries.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 188 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQBoxPlotSeries.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qregexp.sip"
#include <qregexp.h>
#line 191 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQBoxPlotSeries.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 194 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQBoxPlotSeries.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 197 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQBoxPlotSeries.cpp"


class sipQtCharts_QBoxPlotSeries : public ::QtCharts::QBoxPlotSeries
{
public:
    sipQtCharts_QBoxPlotSeries(::QObject*);
    virtual ~sipQtCharts_QBoxPlotSeries();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    bool event(::QEvent*) SIP_OVERRIDE;
    ::QtCharts::QAbstractSeries::SeriesType type() const SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQtCharts_QBoxPlotSeries(const sipQtCharts_QBoxPlotSeries &);
    sipQtCharts_QBoxPlotSeries &operator = (const sipQtCharts_QBoxPlotSeries &);

    char sipPyMethods[8];
};

sipQtCharts_QBoxPlotSeries::sipQtCharts_QBoxPlotSeries(::QObject*a0): ::QtCharts::QBoxPlotSeries(a0), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQtCharts_QBoxPlotSeries::~sipQtCharts_QBoxPlotSeries()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQtCharts_QBoxPlotSeries::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_QtChart_qt_metaobject(sipPySelf, sipType_QtCharts_QBoxPlotSeries);

    return ::QtCharts::QBoxPlotSeries::metaObject();
}

int sipQtCharts_QBoxPlotSeries::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ::QtCharts::QBoxPlotSeries::qt_metacall(_c, _id, _a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_QtChart_qt_metacall(sipPySelf, sipType_QtCharts_QBoxPlotSeries, _c, _id, _a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQtCharts_QBoxPlotSeries::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_QtChart_qt_metacast(sipPySelf, sipType_QtCharts_QBoxPlotSeries, _clname, &sipCpp) ? sipCpp : ::QtCharts::QBoxPlotSeries::qt_metacast(_clname));
}

void sipQtCharts_QBoxPlotSeries::disconnectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[0], &sipPySelf, SIP_NULLPTR, sipName_disconnectNotify);

    if (!sipMeth)
    {
        ::QtCharts::QBoxPlotSeries::disconnectNotify(a0);
        return;
    }

    extern void sipVH_QtChart_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtChart_0(sipGILState, sipImportedVirtErrorHandlers_QtChart_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQtCharts_QBoxPlotSeries::connectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[1], &sipPySelf, SIP_NULLPTR, sipName_connectNotify);

    if (!sipMeth)
    {
        ::QtCharts::QBoxPlotSeries::connectNotify(a0);
        return;
    }

    extern void sipVH_QtChart_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtChart_0(sipGILState, sipImportedVirtErrorHandlers_QtChart_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQtCharts_QBoxPlotSeries::customEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[2], &sipPySelf, SIP_NULLPTR, sipName_customEvent);

    if (!sipMeth)
    {
        ::QtCharts::QBoxPlotSeries::customEvent(a0);
        return;
    }

    extern void sipVH_QtChart_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtChart_1(sipGILState, sipImportedVirtErrorHandlers_QtChart_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQtCharts_QBoxPlotSeries::childEvent(::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[3], &sipPySelf, SIP_NULLPTR, sipName_childEvent);

    if (!sipMeth)
    {
        ::QtCharts::QBoxPlotSeries::childEvent(a0);
        return;
    }

    extern void sipVH_QtChart_2(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QChildEvent*);

    sipVH_QtChart_2(sipGILState, sipImportedVirtErrorHandlers_QtChart_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQtCharts_QBoxPlotSeries::timerEvent(::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[4], &sipPySelf, SIP_NULLPTR, sipName_timerEvent);

    if (!sipMeth)
    {
        ::QtCharts::QBoxPlotSeries::timerEvent(a0);
        return;
    }

    extern void sipVH_QtChart_3(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTimerEvent*);

    sipVH_QtChart_3(sipGILState, sipImportedVirtErrorHandlers_QtChart_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQtCharts_QBoxPlotSeries::eventFilter(::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[5], &sipPySelf, SIP_NULLPTR, sipName_eventFilter);

    if (!sipMeth)
        return ::QtCharts::QBoxPlotSeries::eventFilter(a0, a1);

    extern bool sipVH_QtChart_4(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, ::QEvent*);

    return sipVH_QtChart_4(sipGILState, sipImportedVirtErrorHandlers_QtChart_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

bool sipQtCharts_QBoxPlotSeries::event(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[6], &sipPySelf, SIP_NULLPTR, sipName_event);

    if (!sipMeth)
        return ::QtCharts::QBoxPlotSeries::event(a0);

    extern bool sipVH_QtChart_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_QtChart_5(sipGILState, sipImportedVirtErrorHandlers_QtChart_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

::QtCharts::QAbstractSeries::SeriesType sipQtCharts_QBoxPlotSeries::type() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[7]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_type);

    if (!sipMeth)
        return ::QtCharts::QBoxPlotSeries::type();

    extern ::QtCharts::QAbstractSeries::SeriesType sipVH_QtChart_7(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtChart_7(sipGILState, sipImportedVirtErrorHandlers_QtChart_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}


PyDoc_STRVAR(doc_QtCharts_QBoxPlotSeries_append, "append(self, box: QBoxSet|None) -> bool\n"
"append(self, boxes: Iterable[QBoxSet]) -> bool");

extern "C" {static PyObject *meth_QtCharts_QBoxPlotSeries_append(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QBoxPlotSeries_append(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QtCharts::QBoxSet* a0;
        ::QtCharts::QBoxPlotSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ:", &sipSelf, sipType_QtCharts_QBoxPlotSeries, &sipCpp, sipType_QtCharts_QBoxSet, &a0))
        {
            bool sipRes;

            sipRes = sipCpp->append(a0);

            return PyBool_FromLong(sipRes);
        }
    }

    {
        QList< ::QtCharts::QBoxSet*>* a0;
        int a0State = 0;
        ::QtCharts::QBoxPlotSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ3", &sipSelf, sipType_QtCharts_QBoxPlotSeries, &sipCpp, sipType_QList_0101QtCharts_QBoxSet, &a0, &a0State))
        {
            bool sipRes;

            sipRes = sipCpp->append(*a0);
            sipReleaseType(a0, sipType_QList_0101QtCharts_QBoxSet, a0State);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QBoxPlotSeries, sipName_append, doc_QtCharts_QBoxPlotSeries_append);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QBoxPlotSeries_remove, "remove(self, box: QBoxSet|None) -> bool");

extern "C" {static PyObject *meth_QtCharts_QBoxPlotSeries_remove(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QBoxPlotSeries_remove(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QtCharts::QBoxSet* a0;
        ::QtCharts::QBoxPlotSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8", &sipSelf, sipType_QtCharts_QBoxPlotSeries, &sipCpp, sipType_QtCharts_QBoxSet, &a0))
        {
            bool sipRes;

            sipRes = sipCpp->remove(a0);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QBoxPlotSeries, sipName_remove, doc_QtCharts_QBoxPlotSeries_remove);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QBoxPlotSeries_take, "take(self, box: QBoxSet|None) -> bool");

extern "C" {static PyObject *meth_QtCharts_QBoxPlotSeries_take(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QBoxPlotSeries_take(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QtCharts::QBoxSet* a0;
        ::QtCharts::QBoxPlotSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8", &sipSelf, sipType_QtCharts_QBoxPlotSeries, &sipCpp, sipType_QtCharts_QBoxSet, &a0))
        {
            bool sipRes;

            sipRes = sipCpp->take(a0);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QBoxPlotSeries, sipName_take, doc_QtCharts_QBoxPlotSeries_take);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QBoxPlotSeries_insert, "insert(self, index: int, box: QBoxSet|None) -> bool");

extern "C" {static PyObject *meth_QtCharts_QBoxPlotSeries_insert(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QBoxPlotSeries_insert(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::QtCharts::QBoxSet* a1;
        ::QtCharts::QBoxPlotSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BiJ:", &sipSelf, sipType_QtCharts_QBoxPlotSeries, &sipCpp, &a0, sipType_QtCharts_QBoxSet, &a1))
        {
            bool sipRes;

            sipRes = sipCpp->insert(a0, a1);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QBoxPlotSeries, sipName_insert, doc_QtCharts_QBoxPlotSeries_insert);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QBoxPlotSeries_count, "count(self) -> int");

extern "C" {static PyObject *meth_QtCharts_QBoxPlotSeries_count(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QBoxPlotSeries_count(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtCharts::QBoxPlotSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QBoxPlotSeries, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->count();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QBoxPlotSeries, sipName_count, doc_QtCharts_QBoxPlotSeries_count);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QBoxPlotSeries_boxSets, "boxSets(self) -> list[QBoxSet]");

extern "C" {static PyObject *meth_QtCharts_QBoxPlotSeries_boxSets(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QBoxPlotSeries_boxSets(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtCharts::QBoxPlotSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QBoxPlotSeries, &sipCpp))
        {
            QList< ::QtCharts::QBoxSet*>*sipRes;

            sipRes = new QList< ::QtCharts::QBoxSet*>(sipCpp->boxSets());

            return sipConvertFromNewType(sipRes, sipType_QList_0101QtCharts_QBoxSet, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QBoxPlotSeries, sipName_boxSets, doc_QtCharts_QBoxPlotSeries_boxSets);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QBoxPlotSeries_clear, "clear(self)");

extern "C" {static PyObject *meth_QtCharts_QBoxPlotSeries_clear(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QBoxPlotSeries_clear(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QtCharts::QBoxPlotSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QBoxPlotSeries, &sipCpp))
        {
            sipCpp->clear();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QBoxPlotSeries, sipName_clear, doc_QtCharts_QBoxPlotSeries_clear);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QBoxPlotSeries_type, "type(self) -> QAbstractSeries.SeriesType");

extern "C" {static PyObject *meth_QtCharts_QBoxPlotSeries_type(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QBoxPlotSeries_type(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QtCharts::QBoxPlotSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QBoxPlotSeries, &sipCpp))
        {
            ::QtCharts::QAbstractSeries::SeriesType sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QtCharts::QBoxPlotSeries::type() : sipCpp->type());

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QtCharts_QAbstractSeries_SeriesType);
        }
    }

    sipNoMethod(sipParseErr, sipName_QBoxPlotSeries, sipName_type, doc_QtCharts_QBoxPlotSeries_type);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QBoxPlotSeries_setBoxOutlineVisible, "setBoxOutlineVisible(self, visible: bool)");

extern "C" {static PyObject *meth_QtCharts_QBoxPlotSeries_setBoxOutlineVisible(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QBoxPlotSeries_setBoxOutlineVisible(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0;
        ::QtCharts::QBoxPlotSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bb", &sipSelf, sipType_QtCharts_QBoxPlotSeries, &sipCpp, &a0))
        {
            sipCpp->setBoxOutlineVisible(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QBoxPlotSeries, sipName_setBoxOutlineVisible, doc_QtCharts_QBoxPlotSeries_setBoxOutlineVisible);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QBoxPlotSeries_boxOutlineVisible, "boxOutlineVisible(self) -> bool");

extern "C" {static PyObject *meth_QtCharts_QBoxPlotSeries_boxOutlineVisible(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QBoxPlotSeries_boxOutlineVisible(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QtCharts::QBoxPlotSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QBoxPlotSeries, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->boxOutlineVisible();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QBoxPlotSeries, sipName_boxOutlineVisible, doc_QtCharts_QBoxPlotSeries_boxOutlineVisible);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QBoxPlotSeries_setBoxWidth, "setBoxWidth(self, width: float)");

extern "C" {static PyObject *meth_QtCharts_QBoxPlotSeries_setBoxWidth(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QBoxPlotSeries_setBoxWidth(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::qreal a0;
        ::QtCharts::QBoxPlotSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bd", &sipSelf, sipType_QtCharts_QBoxPlotSeries, &sipCpp, &a0))
        {
            sipCpp->setBoxWidth(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QBoxPlotSeries, sipName_setBoxWidth, doc_QtCharts_QBoxPlotSeries_setBoxWidth);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QBoxPlotSeries_boxWidth, "boxWidth(self) -> float");

extern "C" {static PyObject *meth_QtCharts_QBoxPlotSeries_boxWidth(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QBoxPlotSeries_boxWidth(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QtCharts::QBoxPlotSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QBoxPlotSeries, &sipCpp))
        {
            ::qreal sipRes;

            sipRes = sipCpp->boxWidth();

            return PyFloat_FromDouble(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QBoxPlotSeries, sipName_boxWidth, doc_QtCharts_QBoxPlotSeries_boxWidth);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QBoxPlotSeries_setBrush, "setBrush(self, brush: QBrush|QColor|Qt.GlobalColor|QGradient)");

extern "C" {static PyObject *meth_QtCharts_QBoxPlotSeries_setBrush(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QBoxPlotSeries_setBrush(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QBrush* a0;
        int a0State = 0;
        ::QtCharts::QBoxPlotSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QtCharts_QBoxPlotSeries, &sipCpp, sipType_QBrush, &a0, &a0State))
        {
            sipCpp->setBrush(*a0);
            sipReleaseType(const_cast< ::QBrush *>(a0), sipType_QBrush, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QBoxPlotSeries, sipName_setBrush, doc_QtCharts_QBoxPlotSeries_setBrush);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QBoxPlotSeries_brush, "brush(self) -> QBrush");

extern "C" {static PyObject *meth_QtCharts_QBoxPlotSeries_brush(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QBoxPlotSeries_brush(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtCharts::QBoxPlotSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QBoxPlotSeries, &sipCpp))
        {
            ::QBrush*sipRes;

            sipRes = new ::QBrush(sipCpp->brush());

            return sipConvertFromNewType(sipRes, sipType_QBrush, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QBoxPlotSeries, sipName_brush, doc_QtCharts_QBoxPlotSeries_brush);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QBoxPlotSeries_setPen, "setPen(self, pen: QPen|QColor|Qt.GlobalColor)");

extern "C" {static PyObject *meth_QtCharts_QBoxPlotSeries_setPen(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QBoxPlotSeries_setPen(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPen* a0;
        int a0State = 0;
        ::QtCharts::QBoxPlotSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QtCharts_QBoxPlotSeries, &sipCpp, sipType_QPen, &a0, &a0State))
        {
            sipCpp->setPen(*a0);
            sipReleaseType(const_cast< ::QPen *>(a0), sipType_QPen, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QBoxPlotSeries, sipName_setPen, doc_QtCharts_QBoxPlotSeries_setPen);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QBoxPlotSeries_pen, "pen(self) -> QPen");

extern "C" {static PyObject *meth_QtCharts_QBoxPlotSeries_pen(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QBoxPlotSeries_pen(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtCharts::QBoxPlotSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QBoxPlotSeries, &sipCpp))
        {
            ::QPen*sipRes;

            sipRes = new ::QPen(sipCpp->pen());

            return sipConvertFromNewType(sipRes, sipType_QPen, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QBoxPlotSeries, sipName_pen, doc_QtCharts_QBoxPlotSeries_pen);

    return SIP_NULLPTR;
}


extern "C" {static Py_ssize_t slot_QtCharts_QBoxPlotSeries___len__(PyObject *);}
static Py_ssize_t slot_QtCharts_QBoxPlotSeries___len__(PyObject *sipSelf)
{
    ::QtCharts::QBoxPlotSeries *sipCpp = reinterpret_cast< ::QtCharts::QBoxPlotSeries *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QtCharts_QBoxPlotSeries));

    if (!sipCpp)
        return 0;


    {
        {
            Py_ssize_t sipRes = 0;

#line 1 "Auto-generated"
            sipRes = (Py_ssize_t)sipCpp->count();
#line 866 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQBoxPlotSeries.cpp"

            return sipRes;
        }
    }

    return 0;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QtCharts_QBoxPlotSeries(void *, const sipTypeDef *);}
static void *cast_QtCharts_QBoxPlotSeries(void *sipCppV, const sipTypeDef *targetType)
{
    ::QtCharts::QBoxPlotSeries *sipCpp = reinterpret_cast< ::QtCharts::QBoxPlotSeries *>(sipCppV);

    if (targetType == sipType_QtCharts_QBoxPlotSeries)
        return sipCppV;

    sipCppV = ((const sipClassTypeDef *)sipType_QtCharts_QAbstractSeries)->ctd_cast(static_cast< ::QtCharts::QAbstractSeries *>(sipCpp), targetType);
    if (sipCppV)
        return sipCppV;

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QtCharts_QBoxPlotSeries(void *, int);}
static void release_QtCharts_QBoxPlotSeries(void *sipCppV, int)
{
    ::QtCharts::QBoxPlotSeries *sipCpp = reinterpret_cast< ::QtCharts::QBoxPlotSeries *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void *array_QtCharts_QBoxPlotSeries(Py_ssize_t);}
static void *array_QtCharts_QBoxPlotSeries(Py_ssize_t sipNrElem)
{
    return new ::QtCharts::QBoxPlotSeries[sipNrElem];
}


extern "C" {static void array_delete_QtCharts_QBoxPlotSeries(void *);}
static void array_delete_QtCharts_QBoxPlotSeries(void *sipCpp)
{
    delete[] reinterpret_cast< ::QtCharts::QBoxPlotSeries *>(sipCpp);
}


extern "C" {static void dealloc_QtCharts_QBoxPlotSeries(sipSimpleWrapper *);}
static void dealloc_QtCharts_QBoxPlotSeries(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQtCharts_QBoxPlotSeries *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QtCharts_QBoxPlotSeries(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QtCharts_QBoxPlotSeries(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QtCharts_QBoxPlotSeries(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipQtCharts_QBoxPlotSeries *sipCpp = SIP_NULLPTR;

    {
        ::QObject* a0 = 0;

        static const char *sipKwdList[] = {
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "|JH", sipType_QObject, &a0, sipOwner))
        {
            sipCpp = new sipQtCharts_QBoxPlotSeries(a0);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QtCharts_QBoxPlotSeries[] = {{13, 255, 1}};


/* Define this type's Python slots. */
static sipPySlotDef slots_QtCharts_QBoxPlotSeries[] = {
    {(void *)slot_QtCharts_QBoxPlotSeries___len__, len_slot},
    {0, (sipPySlotType)0}
};


static PyMethodDef methods_QtCharts_QBoxPlotSeries[] = {
    {sipName_append, meth_QtCharts_QBoxPlotSeries_append, METH_VARARGS, doc_QtCharts_QBoxPlotSeries_append},
    {sipName_boxOutlineVisible, meth_QtCharts_QBoxPlotSeries_boxOutlineVisible, METH_VARARGS, doc_QtCharts_QBoxPlotSeries_boxOutlineVisible},
    {sipName_boxSets, meth_QtCharts_QBoxPlotSeries_boxSets, METH_VARARGS, doc_QtCharts_QBoxPlotSeries_boxSets},
    {sipName_boxWidth, meth_QtCharts_QBoxPlotSeries_boxWidth, METH_VARARGS, doc_QtCharts_QBoxPlotSeries_boxWidth},
    {sipName_brush, meth_QtCharts_QBoxPlotSeries_brush, METH_VARARGS, doc_QtCharts_QBoxPlotSeries_brush},
    {sipName_clear, meth_QtCharts_QBoxPlotSeries_clear, METH_VARARGS, doc_QtCharts_QBoxPlotSeries_clear},
    {sipName_count, meth_QtCharts_QBoxPlotSeries_count, METH_VARARGS, doc_QtCharts_QBoxPlotSeries_count},
    {sipName_insert, meth_QtCharts_QBoxPlotSeries_insert, METH_VARARGS, doc_QtCharts_QBoxPlotSeries_insert},
    {sipName_pen, meth_QtCharts_QBoxPlotSeries_pen, METH_VARARGS, doc_QtCharts_QBoxPlotSeries_pen},
    {sipName_remove, meth_QtCharts_QBoxPlotSeries_remove, METH_VARARGS, doc_QtCharts_QBoxPlotSeries_remove},
    {sipName_setBoxOutlineVisible, meth_QtCharts_QBoxPlotSeries_setBoxOutlineVisible, METH_VARARGS, doc_QtCharts_QBoxPlotSeries_setBoxOutlineVisible},
    {sipName_setBoxWidth, meth_QtCharts_QBoxPlotSeries_setBoxWidth, METH_VARARGS, doc_QtCharts_QBoxPlotSeries_setBoxWidth},
    {sipName_setBrush, meth_QtCharts_QBoxPlotSeries_setBrush, METH_VARARGS, doc_QtCharts_QBoxPlotSeries_setBrush},
    {sipName_setPen, meth_QtCharts_QBoxPlotSeries_setPen, METH_VARARGS, doc_QtCharts_QBoxPlotSeries_setPen},
    {sipName_take, meth_QtCharts_QBoxPlotSeries_take, METH_VARARGS, doc_QtCharts_QBoxPlotSeries_take},
    {sipName_type, meth_QtCharts_QBoxPlotSeries_type, METH_VARARGS, doc_QtCharts_QBoxPlotSeries_type}
};

PyDoc_STRVAR(doc_QtCharts_QBoxPlotSeries, "\1QBoxPlotSeries(parent: QObject|None = None)");


/* Define this type's signals. */
static const pyqt5QtSignal signals_QtCharts_QBoxPlotSeries[] = {
    {"doubleClicked(QBoxSet*)|(QtCharts::QBoxSet*)", "\1doubleClicked(self, boxset: QBoxSet|None)", SIP_NULLPTR, SIP_NULLPTR},
    {"released(QBoxSet*)|(QtCharts::QBoxSet*)", "\1released(self, boxset: QBoxSet|None)", SIP_NULLPTR, SIP_NULLPTR},
    {"pressed(QBoxSet*)|(QtCharts::QBoxSet*)", "\1pressed(self, boxset: QBoxSet|None)", SIP_NULLPTR, SIP_NULLPTR},
    {"boxsetsRemoved(QList<QBoxSet*>)|(QList<QtCharts::QBoxSet*>)", "\1boxsetsRemoved(self, sets: Iterable[QBoxSet])", SIP_NULLPTR, SIP_NULLPTR},
    {"boxsetsAdded(QList<QBoxSet*>)|(QList<QtCharts::QBoxSet*>)", "\1boxsetsAdded(self, sets: Iterable[QBoxSet])", SIP_NULLPTR, SIP_NULLPTR},
    {"boxWidthChanged()", "\1boxWidthChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"boxOutlineVisibilityChanged()", "\1boxOutlineVisibilityChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"brushChanged()", "\1brushChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"penChanged()", "\1penChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"countChanged()", "\1countChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"hovered(bool,QBoxSet*)|(bool,QtCharts::QBoxSet*)", "\1hovered(self, status: bool, boxset: QBoxSet|None)", SIP_NULLPTR, SIP_NULLPTR},
    {"clicked(QBoxSet*)|(QtCharts::QBoxSet*)", "\1clicked(self, boxset: QBoxSet|None)", SIP_NULLPTR, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


static pyqt5ClassPluginDef plugin_QtCharts_QBoxPlotSeries = {
    &::QtCharts::QBoxPlotSeries::staticMetaObject,
    0,
    signals_QtCharts_QBoxPlotSeries,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtChart_QtCharts_QBoxPlotSeries = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QtCharts__QBoxPlotSeries,
        SIP_NULLPTR,
        &plugin_QtCharts_QBoxPlotSeries,
    },
    {
        sipNameNr_QBoxPlotSeries,
        {0, 0, 1},
        16, methods_QtCharts_QBoxPlotSeries,
        0, SIP_NULLPTR,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QtCharts_QBoxPlotSeries,
    -1,
    -1,
    supers_QtCharts_QBoxPlotSeries,
    slots_QtCharts_QBoxPlotSeries,
    init_type_QtCharts_QBoxPlotSeries,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QtCharts_QBoxPlotSeries,
    SIP_NULLPTR,
    array_QtCharts_QBoxPlotSeries,
    SIP_NULLPTR,
    release_QtCharts_QBoxPlotSeries,
    cast_QtCharts_QBoxPlotSeries,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QtCharts_QBoxPlotSeries,
    sizeof (::QtCharts::QBoxPlotSeries),
};
